ntrfc.cascade\_case.solution package
====================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   ntrfc.cascade_case.solution.case_modules

Submodules
----------

ntrfc.cascade\_case.solution.ansys module
-----------------------------------------

.. automodule:: ntrfc.cascade_case.solution.ansys
   :members:
   :undoc-members:
   :show-inheritance:

ntrfc.cascade\_case.solution.generic module
-------------------------------------------

.. automodule:: ntrfc.cascade_case.solution.generic
   :members:
   :undoc-members:
   :show-inheritance:

ntrfc.cascade\_case.solution.openfoam module
--------------------------------------------

.. automodule:: ntrfc.cascade_case.solution.openfoam
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ntrfc.cascade_case.solution
   :members:
   :undoc-members:
   :show-inheritance:
